# Makagiga installer/uninstaller script.
# (C) Konrad Twardowski

# NOTE: Do not use UTF-8 encoding here

SetCompressor /SOLID lzma

!include "MUI.nsh"

!define APP_FULL_NAME "Makagiga"
!define APP_FULL_VERSION "0.9.2 Beta"
!define APP_TITLE "${APP_FULL_NAME} ${APP_FULL_VERSION}"

!define APP_INTERNAL_NAME "makagiga"
!define APP_FILE_VERSION "0.9.2_beta"

!define APP_REG "Software\Konrad Twardowski"
!define APP_UNINSTALL_REG "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APP_FULL_NAME}"

Name "${APP_TITLE}"
OutFile "${APP_INTERNAL_NAME}-${APP_FILE_VERSION}.exe"

InstallDir "$PROGRAMFILES\${APP_FULL_NAME}"
InstallDirRegKey HKLM "${APP_REG}\${APP_FULL_NAME}" ""

AutoCloseWindow true

!define MUI_HEADERIMAGE

!insertmacro MUI_PAGE_LICENSE "makagiga-${APP_FILE_VERSION}\LICENSE.txt"
!insertmacro MUI_PAGE_DIRECTORY
!insertmacro MUI_PAGE_INSTFILES

!insertmacro MUI_UNPAGE_CONFIRM
!insertmacro MUI_UNPAGE_INSTFILES

!insertmacro MUI_LANGUAGE "English"
!insertmacro MUI_LANGUAGE "Polish"

# i18n

LangString S_INST_INIT ${LANG_ENGLISH} "WARNING: Quit ${APP_FULL_NAME} before you start the installation."
LangString S_INST_INIT ${LANG_POLISH} "OSTRZEENIE: Zakocz aplikacj ${APP_FULL_NAME}, zanim rozpoczniesz instalacj."

LangString S_INST_SUCCESS ${LANG_ENGLISH} "Installation successful.$\n$\nNOTE: ${APP_FULL_NAME} requires Java 5.0. Would you like to download the Java now?"
LangString S_INST_SUCCESS ${LANG_POLISH} "Instalacja zakoczya si pomylnie.$\n$\nUWAGA: ${APP_FULL_NAME} wymaga Javy 5.0. Czy chcesz pobra Jav teraz?"

LangString S_REPAIR_QUESTION ${LANG_ENGLISH} "Recreate Desktop shortcut?"
LangString S_REPAIR_QUESTION ${LANG_POLISH} "Utworzy ponownie skrt na Pulpicie?"

!define JAVA_ARGS '-Xms16m -Xmx64m -Xverify:none -Djava.library.path="$INSTDIR" -cp "$INSTDIR\makagiga.jar";"$INSTDIR" org.makagiga.Main'

Function CreateShortcuts
	SetShellVarContext all
	CreateShortCut \
		"$DESKTOP\${APP_FULL_NAME}.lnk" \
		"javaw" '${JAVA_ARGS}' "$INSTDIR\makagiga.ico"
	CreateShortCut \
		"$SMPROGRAMS\${APP_FULL_NAME}.lnk" \
		"javaw" '${JAVA_ARGS}' "$INSTDIR\makagiga.ico"
FunctionEnd

Function .onInit
	IfSilent NoInfo
	MessageBox MB_OK $(S_INST_INIT)
NoInfo:
FunctionEnd

Function .onInstSuccess
	IfSilent NoDownload
	MessageBox MB_YESNO $(S_INST_SUCCESS) IDNO NoDownload
	ExecShell "open" "http://java.com/en/download/"
NoDownload:
FunctionEnd

Function un.onInit
	IfSilent NoRepair
	MessageBox MB_YESNO $(S_REPAIR_QUESTION) IDNO NoRepair
	SetShellVarContext all
	CreateShortCut \
		"$DESKTOP\${APP_FULL_NAME}.lnk" \
		"javaw" '${JAVA_ARGS}' "$INSTDIR\makagiga.ico"
	Abort
NoRepair:
FunctionEnd

Section "Makagiga"
	AddSize 1024
	SetOutPath "$INSTDIR"

	Call CreateShortcuts

	File "makagiga-${APP_FILE_VERSION}\*.html"
	File "makagiga-${APP_FILE_VERSION}\*.ico"
	File "makagiga-${APP_FILE_VERSION}\*.jar"
	File "makagiga-${APP_FILE_VERSION}\*.txt"
	CreateDirectory "$INSTDIR\i18n"
	CreateDirectory "$INSTDIR\plugins"

	WriteRegStr HKLM "${APP_UNINSTALL_REG}" "DisplayIcon" "$INSTDIR\makagiga.ico"
	WriteRegStr HKLM "${APP_UNINSTALL_REG}" "DisplayName" "${APP_TITLE}"
#	WriteRegStr HKLM "${APP_UNINSTALL_REG}" "ModifyPath" '"$INSTDIR\Uninstall.exe"'
	WriteRegStr HKLM "${APP_UNINSTALL_REG}" "UninstallString" '"$INSTDIR\Uninstall.exe"'

	WriteRegStr HKLM "${APP_UNINSTALL_REG}" "DisplayVersion" "${APP_FULL_VERSION}"
	WriteRegStr HKLM "${APP_UNINSTALL_REG}" "HelpLink" '"$INSTDIR\README.html"'
	WriteRegStr HKLM "${APP_UNINSTALL_REG}" "Publisher" "Konrad Twardowski"
	WriteRegStr HKLM "${APP_UNINSTALL_REG}" "URLInfoAbout" "http://makagiga.sourceforge.net"
	WriteRegStr HKLM "${APP_UNINSTALL_REG}" "URLUpdateInfo" "http://sourceforge.net/project/showfiles.php?group_id=140641"

#	WriteRegDWORD HKLM "${APP_UNINSTALL_REG}" "NoModify" 1
#	WriteRegDWORD HKLM "${APP_UNINSTALL_REG}" "NoRepair" 1

	WriteRegStr HKLM "${APP_REG}\${APP_FULL_NAME}" "" "$INSTDIR"
	WriteUninstaller "$INSTDIR\Uninstall.exe"
SectionEnd

Section "Uninstall"
	Delete "$INSTDIR\Uninstall.exe"
	# *.html
	Delete "$INSTDIR\README.html"
	# *.ico
	Delete "$INSTDIR\makagiga.ico"
	# *.jar
	Delete "$INSTDIR\i18n.jar"
	Delete "$INSTDIR\images.jar"
	Delete "$INSTDIR\makagiga.jar"
	# *.txt
	Delete "$INSTDIR\LICENSE.txt"

	RMDir "$INSTDIR\i18n"
	RMDir "$INSTDIR\plugins"
	RMDir "$INSTDIR"

	SetShellVarContext all
	Delete "$DESKTOP\${APP_FULL_NAME}.lnk"
	Delete "$SMPROGRAMS\${APP_FULL_NAME}.lnk"

	DeleteRegKey HKLM "${APP_UNINSTALL_REG}"
	DeleteRegKey /ifempty HKLM "${APP_REG}\${APP_FULL_NAME}"
	DeleteRegKey /ifempty HKLM "${APP_REG}"
SectionEnd
