// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga;

// TODO: 2.0: template for new files (color, icon, etc.)
import static org.makagiga.common.UI._;

import org.makagiga.common.*;
import org.makagiga.editors.EditorPlugin;
import org.makagiga.plugins.PluginInfo;
import org.makagiga.plugins.PluginList;

/** The "New File" dialog. */
public final class NewFileDialog extends MDialog implements MDialogAction {

	// private

	private MTextField nameEdit;
	private PluginInfo info;
	private PluginList fileTypes;
	private static String lastNewFileName;
	private String name;

	// public

	/**
	 * Constructs the "New File" dialog.
	 * @param parent A parent frame
	 */
	public NewFileDialog(final MFrame parent) {
		super(parent, _("New File"), STANDARD_DIALOG);
		setSize(480, 320);

		MPanel namePanel = MPanel.createBorderPanel(5);
		// add name label
		MLabel nameLabel = new MLabel(_("&Enter a file name:"));
		namePanel.addWest(nameLabel);
		// add name editor
		nameEdit = new MTextField((lastNewFileName == null) ? _("New File") : lastNewFileName);
// TODO: 2.0: add number to a new name automatically
		add(nameEdit);
		nameLabel.setLabelFor(nameEdit);
		namePanel.addCenter(nameEdit);
		addNorth(namePanel);

		MPanel fileTypesPanel = MPanel.createBorderPanel(5);
		// add file types label
		MLabel fileTypesLabel = new MLabel(_("&Select a file type:"));
		fileTypesPanel.addNorth(fileTypesLabel);
		fileTypes = new PluginList(
			EditorPlugin.TYPE,
			PluginList.PACKED_MODE | PluginList.SHOW_INFO_IF_EMPTY
		);
		fileTypesPanel.addCenter(fileTypes);
		fileTypesLabel.setLabelFor(fileTypes);
		addCenter(fileTypesPanel);

		// select last file type
		fileTypes.selectByID(Config.getGlobal().read("newFile.last"));

		nameEdit.setDefault();

		exec();
	}

	/**
	 * Returns the selected plugin's info.
	 */
	public PluginInfo getInfo() { return info; }

	/**
	 * Returns the entered file name (w/o extension).
	 */
	public String getName() { return name; }

	// MDialogAction

	public void accept() {
		info = fileTypes.getSelectedItem();
		lastNewFileName = nameEdit.getText(); // history

		if ((info == null) || TK.isEmpty(lastNewFileName))
			return;

		Config.getGlobal().write("newFile.last", info.id);

		EditorPlugin.FileType type = EditorPlugin.fromInfo(info).getDefaultType();

		if (type == null) {
			MMessage.error(
				this,
				_("Plugin error. No default type specified.\n\nPlugin: {0}"),
				info.id
			);

			return;
		}
		name = lastNewFileName + type;
	}

	public void reject() {
		info = null;
		name = null;
	}

}
