// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import java.awt.event.ActionEvent;
import javax.swing.AbstractButton;

/** An application action. */
public abstract class AppToggleAction extends AppAction implements Toggleable {

	// private

	private AbstractButton button;
	private boolean selected;

	// public

	/**
	 * @see AppAction::AppAction(final String)
	 */
	public AppToggleAction(final String text) {
		super(text);
	}

	/**
	 * @see AppAction::AppAction(final String, final String)
	 */
	public AppToggleAction(final String text, final String iconName) {
		super(text, iconName);
	}

	/**
	 * @see AppAction::AppAction(final String, final String, final int)
	 */
	public AppToggleAction(final String text, final String iconName, final int keyCode) {
		super(text, iconName, keyCode);
	}

	/**
	 * @see AppAction::AppAction(final String, final String, final int, final int)
	 */
	public AppToggleAction(final String text, final String iconName, final int keyCode, final int modifiers) {
		super(text, iconName, keyCode, modifiers);
	}

	/**
	 * Invoked when an action occurs.
	 * This function calls @ref onToggle.
	 * @param e An action event
	 * @see onToggle
	 */
	public final void actionPerformed(final ActionEvent e) {
		if (e.getSource() instanceof AbstractButton) {
			AbstractButton item = (AbstractButton)e.getSource();
			setSelected(!item.isSelected()); // toggle "selected"
			onToggle(selected);
		}
	}

	/**
	 * Returns @c true if the associated button is selected.
	 */
	public boolean isSelected() { return selected; }

	/**
	 * Changes the selection of the associated button.
	 * @param value @c true to select
	 */
	public void setSelected(final boolean value) {
		selected = value;
		if (button != null) {
			button.setIcon(FS.getIcon(selected ? "ui/checked" : "ui/unchecked", FS.DEFAULT_ICON_SIZE));
			button.setSelected(selected);
		}
	}

	@Override
	public final void onAction() { }

	/**
	 * Sets associated button to @p value.
	 */
	public void setButton(final AbstractButton value) { button = value; }

}
