// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

/** Date/time utils. */
public final class DT {

	// public

	public static final int FULL = DateFormat.FULL;
	public static final int MEDIUM = DateFormat.MEDIUM;
	public static final int SHORT = DateFormat.SHORT;

	// public

	/**
	 * Formats date.
	 * @param date A date to format
	 * @param format A date format (e.g. ""yyyyMMdd-HHmm")
	 */
	public static String format(final Date date, final String format) {
		return new SimpleDateFormat(format).format(date);
	}

	/**
	 * Formats date.
	 * @param date A date to format
	 * @param dateStyle A date format (e.g. @c DT.FULL)
	 * @param timeStyle A time format (e.g. @c DT.SHORT)
	 */
	public static String format(final Date date, final int dateStyle, final int timeStyle) {
		return DateFormat.getDateTimeInstance(dateStyle, timeStyle).format(date);
	}

	/**
	 * Formats date.
	 * @param date A date to format
	 * @param dateStyle A date format (e.g. @c DT.FULL)
	 * @param timeStyle A time format (e.g. @c DT.SHORT)
	 */
	public static String format(final long date, final int dateStyle, final int timeStyle) {
		return format(new Date(date), dateStyle, timeStyle);
	}

	/**
	 * Returns the current date/time.
	 */
	public static Date now() {
		return new Date();
	}

}
