// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import static org.makagiga.common.UI._;

import java.awt.Color;
import java.awt.Dimension;

/**
 * A color button.
 *
 * EXAMPLE:
 * @code
 * ...
 * MColorButton button = new MColorButton() {
 *   @Override
 *   protected void colorChanged() {
 *     Color c = getColor();
 *     doSomethingWith(c);
 *   }
 * }
 * button.setColor(Color.RED);
 * ...
 * @endcode
 */
public class MColorButton extends MButton {

	// public

	public final BooleanProperty updateBackground = new BooleanProperty(true);

	// private

	private Color color;

	// public

	/**
	 * Constructs a new color button with @b null color.
	 * @see setColor
	 */
	public MColorButton() {
		setMinimumSize(new Dimension(32, 32));
		setPreferredSize(getMinimumSize());
		setToolTipText(UI.makeHTML(_("Click to select a color.")));
	}

	public Color getColor() { return color; }

	public void setColor(final Color value) {
		color = value;
		if (updateBackground.get())
			setBackground(color);
	}

	// protected

	/**
	 * Called when user selected a new color.
	 * By default this function does nothing.
	 */
	protected void colorChanged() { }

	@Override
	protected void onClick() {
		Color newColor = MColorChooser.colorBox(null, _("Select a Color"), color);
		if ((newColor != null) && !color.equals(newColor)) {
			setColor(newColor);
			colorChanged();
		}
	}

}
