// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import static java.awt.Color.*;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.event.MouseEvent;
import javax.swing.JComponent;

/**
 * A color picker.
 *
 * EXAMPLE:
 * @code
 * ...
 * MColorPicker picker = new MColorPicker() {
 *   @Override
 *   protected void colorPicked(final Color color) {
 *     // process the "color" value
 *   }
 * };
 * ...
 * @endcode
 */
public class MColorPicker extends MPanel {

	// public

	/**
	 * Constructs a new color picker.
	 */
	public MColorPicker() {
		super(8, 4, 0, 0);
		// red
		addColor(new Color(0x800000), "Dark Red");
		addColor(new Color(0xc00000), "Medium Red");
		addColor(RED, "Red");
		addColor(new Color(0xffc0c0), "Light Red");
		// green
		addColor(new Color(0x008000), "Dark Green");
		addColor(new Color(0x00c000), "Medium Green");
		addColor(GREEN, "Green");
		addColor(new Color(0xc0ffc0), "Light Green");
		// blue
		addColor(new Color(0x000080), "Dark Blue");
		addColor(new Color(0x0000c0), "Medium Blue");
		addColor(BLUE, "Blue");
		addColor(new Color(0xc0c0ff), "Light Blue");
		// yellow
		addColor(new Color(0x808000), "Dark Yellow");
		addColor(new Color(0xc0c000), "Medium Yellow");
		addColor(YELLOW, "Yellow");
		addColor(new Color(0xffffc0), "Light Yellow");
		// cyan
		addColor(new Color(0x008080), "Dark Cyan");
		addColor(new Color(0x00c0c0), "Medium Cyan");
		addColor(CYAN, "Cyan");
		addColor(new Color(0xc0ffff), "Light Cyan");
		// magenta
		addColor(new Color(0x800080), "Dark Magenta");
		addColor(new Color(0xc000c0), "Medium Magenta");
		addColor(MAGENTA, "Magenta");
		addColor(new Color(0xffc0ff), "Light Magenta");
		// orange
		addColor(new Color(0xc05800), "Dark Orange");
		addColor(new Color(0xff8000), "Medium Orange");
		addColor(new Color(0xffa858), "Orange");
		addColor(new Color(0xffdca8), "Light Orange");
		// gray
		addColor(new Color(0xa0a0a0), "Medium Gray");
		addColor(new Color(0xdcdcdc), "Light Gray");
		// black & white
		addColor(BLACK, "Black");
		addColor(WHITE, "White");
	}

	// private

	private void addColor(final Color color, final String name) {
		Button b = new Button(color);
		if (UI.toolTipsDetails.get()) {
			String rgb = String.format("R = %d<br>G = %d<br>B = %d", color.getRed(), color.getGreen(), color.getBlue());
			String triplet = TK.toHTMLTriplet(color);
			b.setToolTipText(UI.makeHTML("<b>" + name + "</b>, " + triplet + "<br>" + rgb));
		}
		else {
			b.setToolTipText(UI.makeHTML(name));
		}
		add(b);
	}

	// protected

	/**
	 * Called when a new color has been selected.
	 * By default this function does nothing.
	 * @param color A picked color
	 */
	protected void colorPicked(final Color color) { };

	// private classes

	private final class Button extends JComponent {

		// public

		public Button(final Color color) {
			Dimension size = new Dimension(24, 12);
			setMaximumSize(size);
			setMinimumSize(size);
			setPreferredSize(size);
			setSize(size);
			setBackground(color);
			setOpaque(true);
			addMouseListener(new MMouseAdapter() {
				@Override
				public void mouseClicked(final MouseEvent e) {
					if (isEnabled())
						colorPicked(getBackground());
				}
			} );
		}

		@Override
		public void paintComponent(final Graphics g) {
			g.setColor(getBackground());
			g.fillRect(0, 0, getWidth(), getHeight());
		}

	}

}
