// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import java.io.File;
import javax.swing.filechooser.FileFilter;

/** A file chooser filter. */
public class MFileFilter extends FileFilter {

	// private

	private String description;
	private String types;

	// public

	/**
	 * Constructs a new file filter.
	 * @param types A file types to display
	 * @param description A file types description
	 * @see MFileChooser.addFilter
	 */
	public MFileFilter(final String types, final String description) {
		this.description = description;
		this.types = types;
	}

	/**
	 * Returns @c true if file @p f has been accepted.
	 * Accepted file will be displayed in the file list.
	 */
	public boolean accept(File f) {
		if (types == null)
			return true;

		if (f == null)
			return false;

		if (f.isDirectory())
			return true;

		String type = FS.getType(f.getPath());

		if (type == null)
			return false;

// TODO: 2.0: multi filter
// FIXME: 2.0: case sensitive
		return type.equalsIgnoreCase(types);
	}

	/**
	 * Returns the filter description in format: DESCRIPTION (*.FILE_EXTENSION).
	 */
	public String getDescription() {
		return String.format("%s (*%s)", description, types);
	}

}
