// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import java.awt.BorderLayout;
import javax.swing.JComponent;
import javax.swing.JFrame;
import javax.swing.JMenuBar;

/** A frame (top-level window). */
public class MFrame extends JFrame implements MBorderLayout {

	// private

	private static MFrame global;

	// public

	/**
	 * Constructs a new frame.
	 */
	public MFrame() { }

	/**
	 * Constructs a new frame.
	 * @param title A frame title
	 */
	public MFrame(final String title) {
		super(title);
	}

	/**
	 * Returns the global frame.
	 * @ref MMainWindow will set global frame to @c this (<code>setGlobal(this);</code>).
	 */
	public static MFrame getGlobal() { return global; }

	/**
	 * Sets global frame to @p value.
	 * Only one frame can be global.
	 */
	public static void setGlobal(final MFrame value) { global = value; }

	/**
	 * Returns the menu bar associated with this frame.
	 * @see MMenuBar
	 */
	public MMenuBar getMMenuBar() {
		JMenuBar menuBar = getJMenuBar();

		return (menuBar instanceof MMenuBar) ? MMenuBar.class.cast(menuBar) : null;
	}

	/**
	 * Sets menu bar to @p value.
	 * @see MMenuBar
	 */
	public void setMMenuBar(final MMenuBar value) {
		setJMenuBar(value);
	}

	// MBorderLayout

	public void addCenter(final JComponent component) {
		UI.addCenter(this, component);
	}

	public void addEast(final JComponent component) {
		add(component, BorderLayout.EAST);
	}

	public void addNorth(final JComponent component) {
		add(component, BorderLayout.NORTH);
	}

	public void addSouth(final JComponent component) {
		add(component, BorderLayout.SOUTH);
	}

	public void addWest(final JComponent component) {
		add(component, BorderLayout.WEST);
	}

}
