// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import javax.swing.Icon;
import javax.swing.JLabel;

/**
 * A label.
 *
 * EXAMPLE:
 * @code
 * ...
 * MLabel label = new MLabel("&Name"); // &N = "n" mnemonic
 * ...
 * @endcode
 */
public class MLabel extends JLabel {

	// private

	private boolean mnemonicEnabled = true;

	// public

	/**
	 * Constructs a label.
	 */
	public MLabel() { }

	/**
	 * Constructs a label.
	 * @param icon An icon
	 */
	public MLabel(final Icon icon) {
		super(icon);
	}

	/**
    * Constructs a label.
	 * @param text A text (&amp; - mnemonic)
	 */
	public MLabel(final String text) {
		setText(text);
	}

	public void setMnemonicEnabled(final boolean value) { mnemonicEnabled = value; }

	/**
	 * Overriden to handle mnemonics.
	 * Use @ref setMnemonicEnabled to disable/enable mnemonics.
	 * @param text A new text (& - mnemonic)
	 */
	@Override
	public void setText(final String text) {
		super.setText(mnemonicEnabled ? UI.setTextWithMnemonic(this, text) : text);
	}

}
