// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

// MUSTANG: import java.awt.SystemTray; (move to org.makagiga.MainWindow and init in separated async. thread)
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import org.makagiga.console.Console;

/** The main window. */
public class MMainWindow extends MFrame {

	// private

	private boolean minimizeOnClose;
	private MStatusBar statusBar;

	// public

	/**
	 * Constructs the main window.
	 */
	public MMainWindow() {
		super(AppInfo.fullName.get());
		setGlobal(this);

		// init system tray
// MUSTANG: SystemTray
/*
		if (SystemTray.isSupported() && (trayIcon == null)) {
			trayIcon = new TrayIcon(FS.getImage("makagiga"), AppInfo.getTitle());
			trayIcon.addMouseListener(new MMouseAdapter() {
				@Override
				public void mouseClicked(final MouseEvent e) {
					setVisible(!isVisible());
				}
			} );
			PopupMenu trayMenu = new PopupMenu();
			MenuItem trayQuitMenuItem = new MenuItem(_("Quit"));
			trayQuitMenuItem.addActionListener(new ActionListener() {
				public void actionPerformed(final ActionEvent e) {
					quit();
				}
			} );
			trayMenu.add(trayQuitMenuItem);
			trayIcon.setPopupMenu(trayMenu);
			SystemTray.getSystemTray().add(trayIcon);
		}
*/

		// add close event handler
		addWindowListener(new WindowAdapter() {
			@Override
			public void windowClosing(final WindowEvent e) {
				if (minimizeOnClose) {
// MUSTANG: SystemTray
/*
					if (SystemTray.isSupported())
						setVisible(false); // hide in tray
					else
*/
					setExtendedState(ICONIFIED); // minimize
				}
				else {
					quit();
				}
			}
// MUSTANG: SystemTray
/*
			@Override
			public void windowIconified(final WindowEvent e) {
				if (SystemTray.isSupported())
					setVisible(false); // hide in tray
			}
*/
		} );

		// add shut down hook (called at application/session exit)
		OS.setShutDownHook(new Thread() {
			public void run() {
				onShutDown();
			}
		} );
	}

	/**
	 * Shows information about this application.
	 */
	public static void about() {
		MAbout about = new MAbout(getGlobal());
		about.exec();
	}

	/**
	 * Constructs and returns the singleton instance of the status bar.
	 * The returned status bar is global.
	 */
	public MStatusBar getStatusBar() {
		if (statusBar == null) {
			statusBar = new MStatusBar();
			statusBar.makeGlobal();
			addSouth(statusBar);
		}

		return statusBar;
	}

	/**
	 * Returns @c true if "minimize instead of close" is enabled.
	 */
	public boolean isMinimizeOnClose() { return minimizeOnClose; }

	/**
	 * Sets "minimize instead of close" feature to @p value.
	 */
	public void setMinimizeOnClose(final boolean value) {
		minimizeOnClose = value;
		setDefaultCloseOperation(minimizeOnClose ? DO_NOTHING_ON_CLOSE : EXIT_ON_CLOSE);
	}

	/**
	 * Quits the application, if @ref onQuit return @c true.
	 * @see onQuit
	 */
	public synchronized final void quit() {
		if (onQuit())
			forceQuit();
// MUSTANG: SystemTray
/*
			if (trayIcon != null)
				SystemTray.getSystemTray().remove(trayIcon);
*/
	}

	// protected

	/**
	 * Quits application ignoring @ref onQuit.
	 */
	protected synchronized void forceQuit() {
		Console.IO.shutDown();
		setGlobal(null); // clear reference

		// It seems that shut down hook must be removed here,
		// or session save will fail.
		OS.removeShutDownHook();

		TK.quit();
	}

	/**
	 * Invoked when the user quits the application.
	 * @return @c true - quit application, @c false - cancel quit
	 */
	protected synchronized boolean onQuit() { return true; }

	/**
	 * Invoked when the program exits normally,
	 * or when the @b JVM is terminated (e.g. system shut down).
	 */
	protected synchronized void onShutDown() { }

}
