// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

/**
 * A mouse adapter.
 *
 * EXAMPLE:
 * @code
 * ...
 * addMouseListener(new MMouseAdapter() {
 *   @Override
 *   public void mouseClicked(final MouseEvent e) {
 *     ...
 *   }
 *   @Override
 *   public void popupTrigger(final MouseEvent e) {
 *     // show context menu here
 *   }
 * } );
 * ...
 * @endcode
 */
public class MMouseAdapter extends MouseAdapter {

	// public

	public static boolean isLeft(final MouseEvent e) {
		return (e.getModifiers() & MouseEvent.BUTTON1_MASK) != 0;
	}

	/**
	 * Overriden to call @ref popupTrigger.
	 * @param e A mouse event
	 */
	@Override
	public void mousePressed(final MouseEvent e) {
		if (e.isPopupTrigger()) {
			e.consume();
			popupTrigger(e);
		}
	}

	/**
	 * Overriden to call @ref popupTrigger.
	 * @param e A mouse event
	 */
	@Override
	public void mouseReleased(final MouseEvent e) {
		if (e.isPopupTrigger()) {
			e.consume();
			popupTrigger(e);
		}
	}

	/**
	 * Override if you want to display a context popup menu.
	 * By default this function does nothing.
	 * @param e A mouse event
	 */
	public void popupTrigger(final MouseEvent e) { }

}
