// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// MUSTANG: native splash screen (http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=4247839)
package org.makagiga.common;

import static javax.swing.SwingConstants.*;

import java.awt.Color;
import java.awt.Image;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import javax.swing.BorderFactory;
import javax.swing.ImageIcon;
import javax.swing.JWindow;
import javax.swing.border.BevelBorder;

/**
 * The splash screen.
 *
 * EXAMPLE:
 * @code
 * ...
 * MSplashScreen ss = MSplashScreen.create(
 *   256, // width
 *   256, // height
 *   myImage // image
 * );
 * ss.start(); // show splash screen
 * ...
 * ss.dispose(); // hide splash screen
 * ...
 * @endcode
 */
public class MSplashScreen extends JWindow {

	// private

	private MLabel label;
	private static MSplashScreen _instance;

	// public

	@Override
	public boolean isOpaque() { return false; }

	/**
	 * Shows the splash screen.
	 * The splash screen is resized to the image width and height.
	 * @param background A background color
	 * @param image An image
	 */
	public static void start(final Color background, final Image image) {
		if (_instance != null)
			return;

		_instance = new MSplashScreen(background, image);
		UI.centerOnScreen(_instance);
		_instance.setVisible(true);
		_instance.label.paintImmediately(0, 0, _instance.getWidth(), _instance.getHeight());
	}

	public static void stop() {
		if (_instance != null) {
			_instance.dispose();
			_instance = null;
		}
	}

	// private

	private MSplashScreen(final Color background, final Image image) {
		setBackground(background);

		label = new MLabel(new ImageIcon(image));
		label.setBackground(background);
		label.setBorder(BorderFactory.createBevelBorder(BevelBorder.RAISED));
		label.setOpaque(true);
		label.setHorizontalAlignment(CENTER);
		label.setVerticalAlignment(CENTER);
		add(label);

		setLocationByPlatform(true);
		setSize(image.getWidth(null) + 2, image.getHeight(null) + 2);

		// close on click
		addMouseListener(new MouseAdapter() {
			@Override
			public void mouseClicked(final MouseEvent e) {
				dispose();
			}
		} );
	}

}
