// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.Timer;

/** A timer. */
public abstract class MTimer extends Timer {

	// public

	/**
	 * A time format.
	 */
	public enum Format {
		MS, /**< Timeout in milliseconds. */
		MINUTES, /**< Timeout in minutes. */
		SECONDS /**< Timeout in seconds. */
	}

	// public

	/**
	 * Constructs a new timer.
	 * @param format A timeout format
	 * @param timeout A timeout
	 * @see Format
	 * @see onTimeout
	 */
	public MTimer(final Format format, final int timeout) {
		super(0, null);
		addActionListener(new ActionListener() {
			public void actionPerformed(final ActionEvent e) {
				onTimeout();
			}
		} );
		setInitialDelay(calcDelay(format, timeout));
	}

	/**
	 * Invoked on timeout.
	 */
	public abstract void onTimeout();

	// private

	private int calcDelay(final Format format, final int timeout) {
		switch (format) {
			case MS:
				return timeout;
			case MINUTES:
				return timeout * 1000 * 60;
			case SECONDS:
				return timeout * 1000;
		}

		return timeout;
	}

}
