// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import java.awt.Color;
import java.awt.Component;
import javax.swing.JComponent;
import javax.swing.JTable;
import javax.swing.table.DefaultTableCellRenderer;

/**
 * A simple list cell renderer.
 * The @ref onRender function is called after @ref getTableCellRendererComponent.
 */
public abstract class SimpleTableCellRenderer<V> extends DefaultTableCellRenderer {
	
	// protected
	
	protected int row;
	protected JTable table;

	// public

	/**
	 * Overriden to call @ref onRender.
	 * @param table A table
	 * @param value A value
	 * @param isSelected @c true if cell is selected
	 * @param hasFocus @c true if cell has focus
	 * @param row A table row
	 * @param column A table column
	 */
	@Override
	@SuppressWarnings("unchecked")
	public Component getTableCellRendererComponent(
		final JTable table,
		final Object value,
		final boolean isSelected,
		final boolean hasFocus,
		final int row,
		final int column
	) {
		super.getTableCellRendererComponent(
			table,
			value,
			isSelected,
			hasFocus,
			row,
			column
		);
		this.row = row;
		this.table = table;
		if (!isSelected)
			setColors(table, this, row);
		onRender((V)value);

		return this;
	}

	/**
	 * Called from @ref getTableCellRendererComponent.
	 * @param value A value
	 */
	public abstract void onRender(final V value);

	public static void setColors(final JTable table, final JComponent component, final int row) {
		if ((row % 2) == 0) {
			// set darker color
			Color color = table.getBackground();
			final float FACTOR = 0.92f;
			color = new Color(
				Math.max((int)(color.getRed() * FACTOR), 0),
				Math.max((int)(color.getGreen() * FACTOR), 0),
				Math.max((int)(color.getBlue() * FACTOR), 0)
			);
			component.setBackground(color);
		}
		else
			component.setBackground(table.getBackground());
	}

}
