// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.console;

import org.makagiga.common.*;
import org.makagiga.plugins.Pluggable;
import org.makagiga.plugins.PluginException;
import org.makagiga.plugins.PluginInfo;
import org.makagiga.plugins.PluginManager;

/** The <b>Console</b> plugin base. */
public abstract class ConsolePlugin implements Pluggable {

	// public

	public static final String TYPE = "console"; /**< The plugin type. */

	// protected

	protected String description; /**< The description of the command. */

	// private

	private static boolean registered;
	private String command;

	// public

	/**
	 * Creates and returns the console command.
	 */
	public abstract ConsoleCommand createCommand();

	/**
	 * Returns the command name.
	 * (e.g. "screenshot")
	 */
	public String getCommand() { return command; }

	public void onDestroy() throws PluginException { }

	public void onInit(final Config config, final PluginInfo info) throws PluginException {
		command = config.read("x.command");

		if (TK.isEmpty(command))
			throw new PluginException("No \"String.x.command\" specified");

		description = info.description.get();
	}

	/**
	 * Registers built-in plugins.
	 * Used in:
	 * - "Console" dialog
	 * - "Plugins" dialog
	 */
	public static void registerBuiltIn() {
		if (registered)
			return;

		registered = true;

		final PluginManager plugins = PluginManager.getInstance();
		plugins.registerInternal("org/makagiga/console/commands/screenshot");
		plugins.registerInternal("org/makagiga/console/commands/secret");
	}

}
