// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.editors.text;

import java.io.BufferedWriter;
import javax.swing.text.html.HTML;
import javax.swing.text.html.HTMLDocument;
import javax.swing.text.html.HTMLEditorKit;

import org.makagiga.common.*;

//!!! .txt editor [0.9.4]
// TODO: 2.0: TEXT_CURSOR
/** The text editor core. */
public final class TextEditorCore extends MTextPane {

	// public

	/**
	 * Constructs a new text editor core.
	 */
	public TextEditorCore() {
		/*
		Keymap keymap = core.getKeymap();
		KeyStroke keyStroke;

// TODO: 2.0: tab input
		// convert 1 "normal tab" to 3 "HTML &nbsp"s
		keyStroke = KeyStroke.getKeyStroke(VK_TAB, 0);
		keymap.addActionForKeyStroke(keyStroke, new DefaultEditorKit.InsertTabAction() {
			@Override
			public void actionPerformed(final ActionEvent e) {
				insertHTML("&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;");
			}
		} );

// TODO: 2.0: space input
		// convert 1 "normal space" to 1 "HTML &nbsp"
		keyStroke = KeyStroke.getKeyStroke(VK_SPACE, 0);
		keymap.removeKeyStrokeBinding(keyStroke);
		keymap.addActionForKeyStroke(keyStroke, new SimpleAction() {
			public void onAction() {
				insertHTML("&nbsp;");
			}
		} );
		*/
	}

	/**
	 * Returns the HTML document used by this editor pane.
	 */
	public HTMLDocument getDoc() {
		return (HTMLDocument)getDocument();
	}

	/**
	 * Returns the HTML editor kit used by this editor pane.
	 */
	public HTMLEditorKit getKit() {
		return (HTMLEditorKit)getEditorKit();
	}

	public void insertHTML(final String code, final HTML.Tag tag) {
		try {
			HTMLDocument doc = getDoc();
			getKit().insertHTML(
				doc,
				getCaretPosition(),
				code,
				0,
				0,
				tag
			);
		}
		catch (Exception exception) {
			MLogger.exception(exception);
		}
	}

	public void saveToFileAsHTML(final String path) throws Exception {
		BufferedWriter writer = null;
		try {
// !!!: CSS: "p" margin-bottom should be zero (?) [0.9.3]
			HTMLDocument doc = getDoc();
			writer = FS.getUTF8Writer(path);
			getKit().write(writer, doc, 0, doc.getLength());
		}
		finally {
			FS.close(writer);
		}
	}

	public void saveToFileAsText(final String path) throws Exception {
		BufferedWriter writer = null;
		try {
			writer = FS.getUTF8Writer(path);
			String s = getPlainText();
			if (s == null)
				writer.newLine();
			else
				writer.write(s);
		}
		finally {
			FS.close(writer);
		}
	}

}
