// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.editors.todo;

import static java.awt.Color.*;

import java.awt.Color;
import java.util.Calendar;
import java.util.Date;

import org.makagiga.common.*;

/** A "Date/Time" column renderer. */
public final class DateTimeRenderer extends SimpleTableCellRenderer<Date> {

	// private

	private static final Color LATER = new Color(0xc0ffc0); // green
	private static final Color TODAY = new Color(0xffdca8); // orange

	// public

	/**
	 * Formats date/time.
	 * @param value A date/time to format
	 */
	public static String formatDate(final Date value) {
		return
			(value.getTime() == 0)
			? ""
			: DT.format(value, DT.SHORT, DT.SHORT);
	}

	/**
	 * Setups the renderer.
	 * @param value A date/time
	 */
	public void onRender(final Date value) {
		final Calendar c = Calendar.getInstance();
		c.setTime(value);
		c.set(Calendar.HOUR, 0);
		c.set(Calendar.MINUTE, 0);
		c.set(Calendar.SECOND, 0);
		c.set(Calendar.MILLISECOND, 0);
		Date now = DT.now();
		// none
		if (value.getTime() != 0) {
			// timeout
			if (now.after(value))
				setBackground(RED);
			// today
			else if (now.after(c.getTime()))
				setBackground(TODAY);
			// later
			else
				setBackground(LATER);
			setForeground(BLACK);
		}

		String s = formatDate(value);
		setText(s);
		setToolTipText("".equals(s) ? null : UI.makeHTML(s, UI.ESCAPE));
	}

}
