// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.editors.todo;

import static java.awt.Color.*;

import java.awt.Component;
import java.util.EventObject;
import javax.swing.BorderFactory;
import javax.swing.DefaultCellEditor;
import javax.swing.JTable;

import org.makagiga.common.*;

/** @b Summary column editor. */
public final class SummaryEditor extends DefaultCellEditor {

	// public

	/**
	 * Constructs a @b Summary column editor.
	 */
	public SummaryEditor() {
		super(new MTextField());
	}

	/**
	 * Returns the editor.
	 * @param table A "todo" table
	 * @param value A summary value
	 * @param isSelected @c true if cell is selected
	 * @param row A row
	 * @param column A column
	 */
	@Override
	public Component getTableCellEditorComponent(
		final JTable table,
		final Object value,
		final boolean isSelected,
		final int row,
		final int column
	) {
		Component c = super.getTableCellEditorComponent(table, value, isSelected, row, column);
		MTextField textField = (MTextField)c;
		textField.setBorder(BorderFactory.createLineBorder(BLACK, 2));
		textField.selectAll();

		return c;
	}

	/**
	 * Returns @c true if editing can be started.
	 */
	@Override
	public boolean isCellEditable(final EventObject e) {
		return true; // single click
	}

}
