// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.editors.todo;

import java.awt.AlphaComposite;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Graphics2D;

import org.makagiga.common.*;

/** The @b Summary column renderer. */
public final class SummaryRenderer extends SimpleTableCellRenderer<String> {

	// public

	/**
	 * Setup renderer here.
	 * @param value A summary text
	 */
	public void onRender(final String value) {
// FIXME: 2.0: squieeze long tool tip
		setToolTipText("".equals(value) ? null : UI.makeHTML(value, UI.ESCAPE));
	}

	/**
	 * Overriden to paint line through over completed items.
	 * @param graphics A graphics
	 */
	@Override
	public void paintComponent(final Graphics graphics) {
		super.paintComponent(graphics);
		
		if (!TodoEditorCore.class.cast(table).isCompleted(row) || TK.isEmpty(getText()))
			return;
		
		Graphics2D g = (Graphics2D)graphics;
		g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER, 0.5f));
		g.setColor(getForeground());
		int y1 = getHeight() / 2;
		FontMetrics fm = g.getFontMetrics(getFont());
		int x2 = Math.min(getWidth() - 5, fm.stringWidth(getText()));
		g.drawLine(5, y1, x2, y1);
	}

}
