// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// TODO: 2.0: remeber last search
// TODO: 2.0: autocomplete
package org.makagiga.internetsearch;

import static org.makagiga.common.UI._;

import org.makagiga.common.*;
import org.makagiga.plugins.PluginInfo;
import org.makagiga.plugins.PluginList;
import org.makagiga.settings.AdvancedSettings;
import org.makagiga.settings.Settings;

/** The <b>Internet Search</b> dialog. */
public final class InternetSearch extends MDialog implements MDialogAction {

	// private

	private MTextField text;
	private PluginList list;

	// public

	/**
	 * Constructs a new dialog.
	 * @param parent A parent frame
	 * @param text A default text to search for (can be @c null)
	 */
	public InternetSearch(final MFrame parent, final String text) {
		super(parent, _("Internet Search"), STANDARD_DIALOG | OPTIONS_BUTTON);
		setSize(480, 320);
		getOptionsButton().setText(_("Configure Browser..."));

		MPanel p = MPanel.createBorderPanel(5);
		MLabel label = new MLabel(_("&Search for:"));
		p.addWest(label);
		this.text = new MTextField(text);
		p.addCenter(this.text);
		label.setLabelFor(this.text);

		addNorth(p);

		InternetSearchPlugin.registerBuiltIn();

		list = new PluginList(
			InternetSearchPlugin.TYPE,
			PluginList.PACKED_MODE | PluginList.SHOW_INFO_IF_EMPTY
		);
		addCenter(list);
		list.selectByID(Config.getGlobal().read("internetSearch.last"));

		this.text.setDefault();

		exec();
	}

	// MDialogAction

	public void accept() {
		PluginInfo info = list.getSelectedItem();
		if (info == null) {
			MLogger.trace();
			MLogger.error("Null info");

			return;
		}
		Config.getGlobal().write("internetSearch.last", info.id);

		// start search
		InternetSearchPlugin.class.cast(info.plugin.get()).search(text.getText());
	}

	public void reject() { }

	// protected

	@Override
	protected void onOptions() {
		Settings.execPage(this, new AdvancedSettings());
	}

}
