// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.internetsearch;

import org.makagiga.Sidebar;
import org.makagiga.common.*;
import org.makagiga.plugins.Pluggable;
import org.makagiga.plugins.PluginException;
import org.makagiga.plugins.PluginInfo;
import org.makagiga.plugins.PluginManager;
import org.makagiga.tools.Browser;

/** The <b>Internet Search</b> plugin base. */
public abstract class InternetSearchPlugin implements Pluggable {

	// public

	public static final String TYPE = "internetsearch"; /**< The plugin type. */

	// private

	private static boolean registered;
	private boolean useInternalBrowser;
	private String url; // null by default

	// public

	public void onDestroy() throws PluginException { }

	public void onInit(final Config config, final PluginInfo info) throws PluginException {
		useInternalBrowser = config.read("x.useInternalBrowser", false);
		url = config.read("x.url");

		if (TK.isEmpty(url))
			throw new PluginException("No \"String.x.url\" specified");
	}

	/**
	 * Registers built-in plugins.
	 * Used in:
	 * - "Internet Search" dialog
	 * - "Plugins" dialog
	 */
	public static void registerBuiltIn() {
		if (registered)
			return;

		registered = true;

		final PluginManager plugins = PluginManager.getInstance();
		plugins.registerInternal("org/makagiga/internetsearch/google");
		plugins.registerInternal("org/makagiga/internetsearch/wikipedia");
	}

	/**
	 * Starts the Internet search.
	 * @param text A text to find
	 */
	public void search(final String text) {
		// {@} = search term
		String query = url.replaceFirst("\\{@\\}", TK.escapeURL(text));
		if (useInternalBrowser) {
			Sidebar.goTo(Sidebar.Tab.BROWSER);
			Browser.getInstance().goTo(query);
		}
		else {
			OS.launchBrowser(query);
		}
	}

}
