// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.plugins;

import org.makagiga.common.*;

/**
 * The plugin interface.
 * Each Makagiga plugin must implement this interface.
 */
public interface Pluggable {

	// public

	/**
	 * Invoked when a plugin is unloaded.
	 * @b NOTE: Currently not used.
	 * @throws PluginException If unload failed
	 */
	public void onDestroy() throws PluginException;

	/**
	 * Invoked when a plugin is loaded.
	 * @b NOTE: This function is called once.
	 * @param config A plugin configuration (each plugin has its own "plugin.properties" file)
	 * @param info A plugin info
	 * @throws PluginException If load failed
	 */
	public void onInit(final Config config, final PluginInfo info) throws PluginException;

}
