// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.plugins;

/**
 * A plugin exception.
 * Plugin that throw this exception will not be register by the plugin manager.
 *
 * EXAMPLE:
 * @code
 * ...
 * public void onInit(final Config config, final PluginInfo info) throws PluginException {
 *   value = config.read("x.myValue");
 *   if (value == null)
 *     throw new PluginException("Could not initialize plugin: Value not found.");
 * }
 * ...
 * @endcode
 * @see Pluggable
 * @see PluginManager
 */
public final class PluginException extends Exception {

	// public

	/**
	 * Constructs a new plugin exception.
	 * @param message A message. This message is printed to @b stderr by the plugin manager.
	 * @see PluginManager
	 */
	public PluginException(final String message) {
		super(message);
	}

}
