// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.settings;

import static org.makagiga.common.UI._;

import org.makagiga.common.*;

// !!!: remember last tab [0.9.3]
/** A settings dialog. */
public abstract class Settings extends MDialog implements MDialogAction {

	// private

	private MTabbedPane<SettingsPage> tabs;

	// public

	/**
	 * Constructs a settings dialog.
	 * @param parent A parent frame
	 * @param title A dialog title
	 * @param flags A dialog flags (e.g. @ref org.makagiga.common.MDialog.STANDARD_DIALOG)
	 */
	public Settings(final MFrame parent, final String title, final int flags) {
		super(parent, title, flags);
		setSize(640, 480);

		tabs = new MTabbedPane<SettingsPage>();
		tabs.setTabPlacement(MTabbedPane.LEFT);
		addCenter(tabs);
	}

	/**
	 * Adds a new page (tab) to the dialog.
	 * @param page A page to add
	 */
	public void addPage(final SettingsPage page) {
		if (page == null)
			return;

		String iconName = page.iconName.get();
		if (iconName == null)
			iconName = "ui/configure";
		tabs.addTab(page.toString(), iconName, page);
		if (page instanceof SettingsAction)
			SettingsAction.class.cast(page).onInit();
	}

	public static void execPage(final MDialog parent, final SettingsPage page) {
		if (page == null)
			return;

		MDialog dialog = new MDialog(parent, page.toString(), MDialog.STANDARD_DIALOG);
		dialog.addCenter(page);
		if (page instanceof SettingsAction)
			SettingsAction.class.cast(page).onInit();
		dialog.pack();
		if (dialog.isOK()) {
			if (page instanceof SettingsAction)
				SettingsAction.class.cast(page).onOK();
			if (page.needRestart.get())
				setNeedRestart();
		}
	}

	// MDialogAction

	public void accept() {
		boolean needRestart = false;

		for (SettingsPage i : tabs) {
			if (i instanceof SettingsAction)
				SettingsAction.class.cast(i).onOK();
			if (i.needRestart.get())
				needRestart = true;
		}
		Config.getGlobal().saveToFile();

		if (needRestart)
			setNeedRestart();
	}

	public void reject() { }

	// private

	private static void setNeedRestart() {
		MStatusBar.setWarning(_("Restart application to apply changes."));
	}

}
