// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.settings;

import org.makagiga.common.*;

/** An abstract settings page. */
public abstract class SettingsPage extends MPanel {

	// public

	/**
	 * @c true if application should be restarted to apply the new settings.
	 */
	public final BooleanProperty needRestart = new BooleanProperty();

	/**
	 * An icon name. (e.g. "console")
	 */
	public final StringProperty iconName = new StringProperty();

	/**
	 * A page title. (e.g. "My Settings")
	 */
	public final StringProperty text = new StringProperty();

	// public

	/**
	 * Constructs a settings page.
	 */
	public SettingsPage() { }

	/**
	 * Constructs a settings page.
	 * @param text A page title (e.g. "My Settings")
	 */
	public SettingsPage(final String text) {
		this.text.set(text);
	}

	/**
	 * Constructs a settings page.
	 * @param text A page title (e.g. "My Settings")
	 * @param iconName An icon name (e.g. "console")
	 */
	public SettingsPage(final String text, final String iconName) {
		this.text.set(text);
		this.iconName.set(iconName);
	}

	/**
	 * Returns the page title.
	 */
	@Override
	public String toString() { return text.toString(); }

}
