// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// TODO: 2.0: bookmark all open tabs as group
// !!!: right mouse button = context menu
package org.makagiga.tools;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;

import org.makagiga.MetaInfo;
import org.makagiga.Tabs;
import org.makagiga.common.*;
import org.makagiga.tree.TreeList;

/** A bookmark manager. */
public final class Bookmarks {

	// private

	private static Bookmarks _instance;

	// public

	/**
	 * Creates and returns the instance of the bookmark manager.
	 */
	public static Bookmarks getInstance() {
		if (_instance == null)
			_instance = new Bookmarks();

		return _instance;
	}

	/**
	 * Adds bookmarks to the @p menu.
	 */
	public void updateMenu(final MMenu menu) {
		final ArrayList<MetaInfo> bookmarks = new ArrayList<MetaInfo>();
		new MTreeScanner<MetaInfo>(TreeList.getInstance().getDataRoot()) {
			public void processItem(final MTreeItem<MetaInfo> item) {
				MetaInfo metaInfo = item.getData();
				if (metaInfo.bookmark.get())
					bookmarks.add(metaInfo);
			}
		};
// !!!: common comparator code with Search.java
		Collections.sort(bookmarks, new Comparator<MetaInfo>() {
			public int compare(MetaInfo o1, MetaInfo o2) {
				int i = Float.valueOf(o1.getRatio()).compareTo(Float.valueOf(o2.getRatio()));

				return (i == 0) ? o1.toString().compareTo(o2.toString()) : (i * -1);
			}
		} );
		for (MetaInfo i : bookmarks)
			menu.add(new BookmarkAction(i));
	}

	// private

	private Bookmarks() { }

	// private classes

	private static final class BookmarkAction extends AppAction {

		// private

		private MetaInfo metaInfo;

		// public

		public BookmarkAction(final MetaInfo metaInfo) {
			super(metaInfo.getNicePath());
			this.metaInfo = metaInfo;
			setIcon(metaInfo.getIcon());
			setHTMLHelp(metaInfo.getToolTipText());
		}

		public void onAction() {
			Tabs.getInstance().openEditor(metaInfo);
		}

	}

}
