// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.tree;

import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;

import org.makagiga.MetaInfo;
import org.makagiga.common.*;
import org.makagiga.plugins.PluginInfo;

/** A tree list item. */
public final class TreeListItem extends MTreeItem<MetaInfo> implements Transferable {

	// public

	/**
	 * Creates and returns a @b file item.
	 * @param path A full path to the file
	 * @param info A plugin info associated with this file type
	 */
	public static TreeListItem createFileItem(final String path, final PluginInfo info) {
		TreeListItem item = new TreeListItem();
		MetaInfo metaInfo = new MetaInfo(path, MetaInfo.FILE);
		item.setData(metaInfo);
		if (!metaInfo.isCustomIcon())
			metaInfo.setIcon(info.getIcon());

		return item;
	}

	/**
	 * Creates and returns a @b folder item.
	 * @param path A full path to the directory
	 */
	public static TreeListItem createFolderItem(final String path) {
		TreeListItem item = new TreeListItem();
		item.setData(new MetaInfo(path, MetaInfo.FOLDER));

		return item;
	}

	/**
	 * Creates and returns a tree list item.
	 * @param path A full path to the file or directory
	 * @param attr A meta info attributes (e.g. @ref org.makagiga.MetaInfo.DATA_ROOT)
	 */
	public static TreeListItem createItem(final String path, final int attr) {
		TreeListItem item = new TreeListItem();
		item.setData(new MetaInfo(path, attr));

		return item;
	}

	// transferable

	public Object getTransferData(final DataFlavor flavor) {
		return getData();
	}

	public DataFlavor[] getTransferDataFlavors() {
		DataFlavor[] flavors = {
			new DataFlavor(TreeListItem.class, "Tree List Item")
// TODO: 2.0: DataFlavor.javaFileListFlavor (import/export)
		};

		return flavors;
	}

	public boolean isDataFlavorSupported(final DataFlavor flavor) {
		return flavor.getDefaultRepresentationClass() == TreeListItem.class;
// TODO: 2.0: flavor.equals(DataFlavor.javaFileListFlavor);
	}

	// private

	private TreeListItem() { }

}
